@@ -25,7 +25,7 @@ def publish(topic, body=None, path=None, json_encoder=None) -> None:
     message = json.dumps(message, cls=json_encoder)
     message = json.dumps({"default": message})
     resp = client.publish(
-        TopicArn=f'{settings.AWS_SNS_PATH}{topic}',
+        TopicArn=f'{settings.AWS_SNS_PATH}{settings.ENVIRONMENT}-{topic}',
         Message=message,
         MessageStructure="json",
     )
